@@ -39,6 +39,7 @@ unsigned Bayonne::idle_count = 0;
 unsigned Bayonne::idle_limit = 0;
 bool Bayonne::shutdown_flag = false;
 time_t Bayonne::start_time = 0;
+AtomicCounter Bayonne::libexec_count = 0;
 
 Audio::Encoding Bayonne::peer_encoding = Audio::unknownEncoding;
 Audio::timeout_t Bayonne::peer_framing = 0;
@@ -68,13 +69,14 @@ Bayonne::statetab Bayonne::states[] = {
 	{"play", &BayonneSession::statePlay, 'p'},
 	{"record", &BayonneSession::stateRecord, 'r'},
 	{"join", &BayonneSession::stateJoin, 'j'},
-	{"wait", &BayonneSession::stateWait, 'w'},
+	{"accept", &BayonneSession::stateWait, 'w'},
 	{"connect", &BayonneSession::stateConnect, 'd'},
 	{"sleep", &BayonneSession::stateSleep, 's'},
 	{"start", &BayonneSession::stateStart, 's'},
 	{"hangup", &BayonneSession::stateHangup, 'h'},
 	{"reset", &BayonneSession::stateLibreset, 'e'},
-	{"inwait", &BayonneSession::stateWaitkey, 'c'}, 
+	{"keywait", &BayonneSession::stateWaitkey, 'c'}, 
+	{"wait", &BayonneSession::stateLibwait, 's'},
 	{"final", &BayonneSession::stateFinal, ' '},
 	{NULL, NULL, ' '}};
 
@@ -397,6 +399,47 @@ compile:
 	}
 }
 
+void Bayonne::compileApps(const char *prefix, ScriptCompiler *img)
+{
+	Dir dir(prefix);
+	char path[256];
+	const char *ext;
+	const char *file;
+	unsigned len;
+	char *pp;
+	
+	slog.info("apps scanning %s", prefix);
+	setString(path, sizeof(path), prefix);
+	len = strlen(path);
+	pp = path + len;
+	len = sizeof(path) - len;
+
+	*pp++ = '/';
+	--len;
+
+	while(NULL != (file = dir.getName()))
+	{
+		ext = strrchr(file, '.');
+		if(ext && !stricmp(ext, ".app"))
+			goto compile;
+
+		if(ext && !stricmp(ext, ".apps"))
+			goto compile;
+
+#ifndef	WIN32
+		if(ext && !stricmp(ext, ".exec"))
+			goto compile;
+#endif
+
+		continue;
+compile:
+
+		setString(pp, len, file);
+		img->compile(path);
+	}
+}
+
+
 bool Bayonne::service(const char *id)
 {
 	bool rtn = false;
@@ -499,6 +542,14 @@ compile:
 		else
 			slog.error() << prefix << ": directory missing" << endl;
 	}
+	prefix = server->getLast("apps");
+	if(prefix)
+	{
+		if(isDir(prefix))
+			compileApps(prefix, img);
+		else
+			slog.error() << prefix << ": directory missing" << endl;
+	}
 
 	img->commit();
 	lock.leave();
