@@ -112,6 +112,7 @@ public:
 	static Audio::timeout_t peer_framing;
 	static BayonneTranslator *init_translator;
 	static const char *init_voicelib;
+	static AtomicCounter libexec_count;
 
 	/**
 	 * Telephony endpoint interface identifiers.
@@ -188,6 +189,7 @@ public:
 		STATE_HANGUP,
 		STATE_LIBRESET,
 		STATE_WAITKEY,
+		STATE_LIBWAIT,
 		STATE_FINAL,
 
 		STATE_STANDBY = STATE_DOWN,
@@ -554,6 +556,12 @@ public:
 
 		union
 		{
+			struct
+			{
+				unsigned count;
+				timeout_t interval;
+			}	wait;
+
 			struct
 			{
 				Audio::Mode mode;
@@ -674,6 +682,14 @@ public:
 	 */
 	static void compileDir(const char *prefix, ScriptCompiler *img);
 
+	/**
+	 * Used internally to compile libexec apps wrappers.
+	 *
+	 * @param directory prefix to compile.
+	 * @param script image to build into.
+	 */
+	static void compileApps(const char *prefix, ScriptCompiler *img);
+
 	/**
 	 * Returns a session pointer for a server timeslot.  Each
 	 * server timeslot can map to a single session object.
@@ -1670,6 +1686,7 @@ protected:
 	bool stateRunning(Event *event);
 	bool stateLibexec(Event *event);
 	bool stateLibreset(Event *event);
+	bool stateLibwait(Event *event);
 	bool stateWaitkey(Event *event);
 	bool stateThreading(Event *event);
 	bool stateHangup(Event *event);
