@@ -490,11 +490,14 @@ bool BayonneSysexec::create(BayonneSession *s)
 	if(iopair[1] < 0)
 		return false;
 
-	if(!strnicmp(line->cmd, "exec", 4))
+	if(!strnicmp(line->cmd, "exec", 4) && strstr(scr->name, "::"))
 		lib = scr->name;
 	else
 		lib = s->getValue();
 
+	if(!strnicmp(lib, "libexec::", 9))
+		lib += 9; 
+
 	s->newTid();
 	snprintf(buf, sizeof(buf), "%04d+%08lx %s", 
 		s->getSlot(), s->newTid(), lib);
