@@ -224,6 +224,12 @@ uint32 BayonneSession::newTid(void)
 	if(state.pid)
 		libClose("901 TERMINATE\n\n");
 
+	if(state.lib)
+	{
+		--libexec_count;
+		state.lib = NULL;
+	}
+
 	state.pid = 0;
 	snprintf(var_tid, sizeof(var_tid), "%04d+%08lx", timeslot, ++tseq);
 	return tseq;
@@ -1154,6 +1160,12 @@ const char *BayonneSession::getAudio(bool live)
 	audio.offset = getKeyword("position");
 	audio.prefixdir = cp = getKeyword("prefix");
 
+	if(cp && !*cp)
+	{
+		cp = NULL;
+		audio.prefixdir = NULL;
+	}
+
 	if(cp)
 	{
 		if(*cp == '/' || *cp == '\\' || cp[1] == ':')
