@@ -15,6 +15,9 @@
 // Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
 #include "engine.h"
+#ifdef	HAVE_LIBEXEC
+#include "libexec.h"
+#endif
 
 using namespace ost;
 using namespace std;
@@ -69,6 +72,11 @@ bool BayonneSession::stateLibexec(Event *event)
 			setRunning();
 			return true;
 		}
+		if(!state.lib)
+		{
+			setRunning();
+			return true;
+		}
 		clrAudio();
 		if(state.pid && state.pfd != PFD_INVALID)
 		{
@@ -152,6 +160,38 @@ timer:
 	return enterCommon(event);
 }
 		
+bool BayonneSession::stateLibwait(Event *event)
+{
+	switch(event->id)
+	{
+	case TIMER_EXPIRED:
+	case ENTER_STATE:
+#ifdef	HAVE_LIBEXEC
+		if(++libexec_count <= state.wait.count || !state.wait.count)
+		{
+			if(!BayonneSysexec::create(this))
+			{
+				--libexec_count;
+				error("libexec-failed");
+				setRunning();
+				return true;
+			}
+			state.lib = getLine();
+			setState(STATE_LIBEXEC);
+			return true;
+		}
+		--libexec_count;
+		startTimer(state.wait.interval);
+		return true;
+#else
+		error("libexec-unsupported");
+		setRunning();
+		return true;
+#endif
+	}
+	return enterCommon(event);
+}
+
 bool BayonneSession::stateLibreset(Event *event)
 {
 	switch(event->id)
