@@ -330,11 +330,17 @@ void BayonneTSession::sysArgs(const char *tsid)
 					*up = '_';
 				++up;
 			}
-			libWrite(buf);
-			cp = getContent(cp);
-			if(cp && *cp)
-				libWrite(cp);
-			libWrite("\n");
+			if(*cp == '&')
+				cp = getSymbol(++cp);
+			else
+				cp = getContent(cp);
+			if(cp)
+			{
+				libWrite(buf);
+				if(*cp)
+					libWrite(cp);
+				libWrite("\n");
+			}
 		}
 		libWrite("\n");
 	}
