@@ -352,7 +352,7 @@ get:
 			return "libexec arguments must be variables";
 	}
 
-	if(!useKeywords(line, "=token=results=prefix=encoding=framing=voice=extension=timeout"))
+	if(!useKeywords(line, "=token=results=prefix=encoding=framing=voice=extension=timeout=limit=interval"))
 		return "invalid keyword used in libexec";
 
 	cp = findKeyword(line, "results");
