@@ -52,6 +52,7 @@ using namespace std;
 #ifdef	WIN32
 #define	PROMPT_FILES	"C:\\Program Files\\GNU Telephony\\Bayonne Audio"
 #define	SCRIPT_FILES	"C:\\Program Files\\GNU Telephony\\Bayonne Scripts"
+#define	MACRO_FILES	"C:\\Program Files\\GNU Telephony\\Bayonne Macros"
 #define	VAR_FILES	"C:\\Program Files\\GNU Telephony\\Bayonne Files"
 #define	LOG_FILES	"C:\\Program Files\\GNU Telephony\\Bayonne Logs"
 #define	CONFIG_FILES	"C:\\Program Files\\GNU Telephony\\Bayonne Config"
@@ -82,10 +83,12 @@ static Keydata::Define paths[] = {
 	{"logfiles", LOG_FILES},
 	{"runfiles", RUN_FILES},
 	{"config", CONFIG_FILES},
+	{"apps", CONFIG_FILES},
 	{"modules", MODULE_FILES},
 	{"drivers", DRIVER_FILES},
 	{"phrases", PHRASE_FILES},
 	{"scripts", SCRIPT_FILES},
+	{"macros", MACRO_FILES},
 	{"prompts", PROMPT_FILES},
 	{NULL, NULL}};
 
@@ -266,8 +269,8 @@ static void commonConfig(void)
                 keypaths.getLast("logfiles"), keyserver.getLast("node"));
         runtime.setValue("stats", path);
 
-	runtime.setValue("include", keypaths.getLast("scripts"));
-	keypaths.setValue("include", keypaths.getLast("scripts"));
+	runtime.setValue("include", keypaths.getLast("macros"));
+	keypaths.setValue("include", keypaths.getLast("macros"));
 	runtime.setValue("tmp", keypaths.getLast("tmp"));
 	runtime.setValue("tmpfs", keypaths.getLast("tmpfs"));
 	runtime.setValue("prompts", keypaths.getLast("prompts"));
@@ -350,6 +353,7 @@ void testConfig(char *argv0)
 #endif
 	keypaths.setValue("prompts", "../audio");
 	keypaths.setValue("scripts", "../scripts");
+	keypaths.setValue("macros", "../scripts");
 	keypaths.setValue("config", "../config");
 	Process::setEnv("DRIVERCONFIG", "../config/driver.conf", true);
 	Process::setEnv("MODULECONFIG", "../config/module.conf", true);
@@ -372,6 +376,7 @@ void testConfig(char *argv0)
 	keypaths.setValue("phrases", "../modules/languages/.libs");
 	keypaths.setValue("prompts", SOURCE_FILES "/audio");
 	keypaths.setValue("scripts", SOURCE_FILES "/scripts");
+	keypaths.setValue("macros", SOURCE_FILES "/macros");
 	keypaths.setValue("config", SOURCE_FILES "/config");
 #endif
 	keypaths.setValue("datafiles", "tempfiles");
@@ -415,9 +420,6 @@ void loadConfig(void)
 	if(!isDir(keypaths.getLast("config")))
 		keypaths.setValue("config", "/etc/bayonne");
 
-	if(!isDir(keypaths.getLast("scripts")))
-		keypaths.setValue("scripts", "/etc/bayonne.d");
-
 	if(home)
 		snprintf(homepath, sizeof(homepath), "%s/.bayonne", home);
 	else
@@ -430,11 +432,15 @@ void loadConfig(void)
 		keyengine.load("~bayonne/engine");
 	}
 
-	umask(007);
-
 	Process::setGroup(keyserver.getLast("group"));
-		
-	Dir::create(keypaths.getLast("datafiles"));
+	if(getuid())
+		Dir::create(keypaths.getLast("datafiles"));
+	else
+	{
+		umask(002);
+		mkdir(keypaths.getLast("datafiles"), 02775);
+	}
+	umask(007);
 	Dir::create(keypaths.getLast("runfiles"));
 	Dir::create(keypaths.getLast("logfiles"));
 
@@ -468,6 +474,13 @@ live:
 #endif
 	chdir(keypaths.getLast("datafiles"));
 	keyserver.setValue("state", "live");
+
+	// only for live server...
+
+#ifdef	SCRIPT_APPS_WRAPPER
+	runtime.setValue("apps", keypaths.getLast("apps"));
+#endif
+
 	commonConfig();
 }
 
