@@ -1,4 +1,6 @@
 #!/bin/sh
+#bayonne: echo "*** BAYONNE LIBEXEC SHELL STARTUP ***"
+#
 # Copyright (C) 2005 Open Source Telecom Corp.
 #
 # This file is free software; as a special exception the author gives
@@ -16,10 +18,13 @@
 prefix=`pwd`
 echo "*** STARTUP LIBEXEC" >&2
 echo "*** LIBEXEC PATH $PATH" >&2
+echo "*** LIBEXEC EXEC $SERVER_LIBEXEC" >&2
 echo "*** LIBEXEC HOME $HOME" >&2
 echo "*** LIBEXEC PERL $PERL5LIB" >&2
 echo "*** LIBEXEC PYTHON $PYTHONPATH" >&2
 echo "*** LIBEXEC DIR $prefix" >&2
+echo "*** LIBEXEC SCR $SERVER_SCRIPTS" >&2
+echo "*** LIBEXEC SYS $SERVER_SYSEXEC" >&2
 
 # issue head command using session id and report server headers
 echo "$PORT_TSESSION head"
